/*

    Boolean Expression Solver
    Version 2.0

    Header parser.h
    For detailed description see parser.c.

    Dialect : ANSI C
    Compiler: any ANSI C-compatible

    Copyright (c) Kamil Ekstein, 2008
    Seminar work of `Programming in C'

    This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
    INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE. Kamil Ekstein reserves all rights not expressly
    granted herein.

*/

#ifndef _PARSER_H
#define _PARSER_H

#include "scan.h"
#include "tree.h"

/* ____________________________________________________________________________

    Preprocessor-defined Symbols
   ____________________________________________________________________________
*/

/* operations in the nodes of the parse tree */
#define OP_NEGATION         1
#define OP_CONJUNCTION      2
#define OP_DISJUNCTION      3
#define OP_EXCL_DISJUNCTION 4
#define OP_IMPLICATION      5
#define OP_EQUIVALENCE      6
#define OP_HOLDS_VAR        7
#define OP_HOLDS_NEG_VAR    8
#define OP_HOLDS_TRUE       9
#define OP_HOLDS_FALSE      10

/* other constants */
#define MAX_VARTABLE_LENGTH 64

/* ____________________________________________________________________________

    Structures and Datatypes
   ____________________________________________________________________________
*/

typedef struct {
    char name[MAX_IDENTIFIER_LENGTH];
    int value;
} variable_t;                       /* variable table entry struct */

/* ____________________________________________________________________________

    Global Module Variables
   ____________________________________________________________________________
*/

extern int var_index;               /* index to variable table */
extern variable_t var_table[];      /* table of recognized variables */

/* ____________________________________________________________________________

    Function Prototypes
   ____________________________________________________________________________
*/

char *name_operation(char opcode);  /* converts small # opcode to string name of the operation */
node_t *parse();                    /* main parser function */

#endif
