/*

    Boolean Expression Solver
    Version 2.0

    Header scan.h
    For detailed description see scan.c.

    Dialect : ANSI C
    Compiler: any ANSI C-compatible

    Copyright (c) Kamil Ekstein, 2008
    Seminar work of `Programming in C'

    This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
    INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE. Kamil Ekstein reserves all rights not expressly
    granted herein.

*/

#ifndef _SCAN_H
#define _SCAN_H

/* ____________________________________________________________________________

    Preprocessor-defined Symbols
   ____________________________________________________________________________
*/

/* lexical analysis tokens */
#define TOK_UNKNOWN             0
#define TOK_NEGATION            1
#define TOK_CONJUNCTION         2
#define TOK_DISJUNCTION         3
#define TOK_EXCL_DISJUNCTION    4
#define TOK_IMPLICATION         5
#define TOK_EQUIVALENCE         6
#define TOK_LPAR                7
#define TOK_RPAR                8
#define TOK_TRUE                9
#define TOK_FALSE              10
#define TOK_VAR                11
#define TOK_STOPPER            12       /* stopper as a parser symbol */
#define LAT_STOPPER          0xFF       /* stopper as a scanner char */

/* other constants */
#define MAX_IDENTIFIER_LENGTH 32
#define MAX_INPUT_LENGTH 256

/* ____________________________________________________________________________

    Structures and Datatypes
   ____________________________________________________________________________
*/

typedef struct {
    int code;
    char value[MAX_IDENTIFIER_LENGTH];
} token_t;

/* ____________________________________________________________________________

    Global Module Variables
   ____________________________________________________________________________
*/

extern char input[];
extern int inp_index;

/* ____________________________________________________________________________

    Function Prototypes
   ____________________________________________________________________________
*/

int fully_analyzed();
char *name_token(int tok_code);
void scan(token_t *token);

#endif
